@@ -122,6 +122,30 @@ pub mod blockchain_events_callbacks_limit_reached;
 pub use self::blockchain_events_callbacks_limit_reached::BlockchainEventsCallbacksLimitReached;
 pub mod blockchain_events_callbacks_limit_reached_error;
 pub use self::blockchain_events_callbacks_limit_reached_error::BlockchainEventsCallbacksLimitReachedError;
+pub mod broadcast_locally_signed_transaction_r;
+pub use self::broadcast_locally_signed_transaction_r::BroadcastLocallySignedTransactionR;
+pub mod broadcast_locally_signed_transaction_r_data;
+pub use self::broadcast_locally_signed_transaction_r_data::BroadcastLocallySignedTransactionRData;
+pub mod broadcast_locally_signed_transaction_rb;
+pub use self::broadcast_locally_signed_transaction_rb::BroadcastLocallySignedTransactionRb;
+pub mod broadcast_locally_signed_transaction_rb_data;
+pub use self::broadcast_locally_signed_transaction_rb_data::BroadcastLocallySignedTransactionRbData;
+pub mod broadcast_locally_signed_transaction_rb_data_item;
+pub use self::broadcast_locally_signed_transaction_rb_data_item::BroadcastLocallySignedTransactionRbDataItem;
+pub mod broadcast_locally_signed_transaction_ri;
+pub use self::broadcast_locally_signed_transaction_ri::BroadcastLocallySignedTransactionRi;
+pub mod broadcast_transaction_fail;
+pub use self::broadcast_transaction_fail::BroadcastTransactionFail;
+pub mod broadcast_transaction_fail_data;
+pub use self::broadcast_transaction_fail_data::BroadcastTransactionFailData;
+pub mod broadcast_transaction_fail_data_item;
+pub use self::broadcast_transaction_fail_data_item::BroadcastTransactionFailDataItem;
+pub mod broadcast_transaction_success;
+pub use self::broadcast_transaction_success::BroadcastTransactionSuccess;
+pub mod broadcast_transaction_success_data;
+pub use self::broadcast_transaction_success_data::BroadcastTransactionSuccessData;
+pub mod broadcast_transaction_success_data_item;
+pub use self::broadcast_transaction_success_data_item::BroadcastTransactionSuccessDataItem;
 pub mod coins_forwarding_automations_limit_reached;
 pub use self::coins_forwarding_automations_limit_reached::CoinsForwardingAutomationsLimitReached;
 pub mod coins_forwarding_automations_limit_reached_error;
@@ -204,8 +228,8 @@ pub mod create_coins_transaction_request_from_wallet_rb_data;
 pub use self::create_coins_transaction_request_from_wallet_rb_data::CreateCoinsTransactionRequestFromWalletRbData;
 pub mod create_coins_transaction_request_from_wallet_rb_data_item;
 pub use self::create_coins_transaction_request_from_wallet_rb_data_item::CreateCoinsTransactionRequestFromWalletRbDataItem;
-pub mod create_coins_transaction_request_from_wallet_rb_data_item_destinations;
-pub use self::create_coins_transaction_request_from_wallet_rb_data_item_destinations::CreateCoinsTransactionRequestFromWalletRbDataItemDestinations;
+pub mod create_coins_transaction_request_from_wallet_rb_data_item_recipients;
+pub use self::create_coins_transaction_request_from_wallet_rb_data_item_recipients::CreateCoinsTransactionRequestFromWalletRbDataItemRecipients;
 pub mod create_coins_transaction_request_from_wallet_ri;
 pub use self::create_coins_transaction_request_from_wallet_ri::CreateCoinsTransactionRequestFromWalletRi;
 pub mod create_coins_transaction_request_from_wallet_ri_recipients;
@@ -226,12 +250,12 @@ pub mod create_tokens_transaction_request_from_address_ri_recipients;
 pub use self::create_tokens_transaction_request_from_address_ri_recipients::CreateTokensTransactionRequestFromAddressRiRecipients;
 pub mod create_tokens_transaction_request_from_address_ri_senders;
 pub use self::create_tokens_transaction_request_from_address_ri_senders::CreateTokensTransactionRequestFromAddressRiSenders;
-pub mod create_tokens_transaction_request_from_address_ri_token_type_specific_data;
-pub use self::create_tokens_transaction_request_from_address_ri_token_type_specific_data::CreateTokensTransactionRequestFromAddressRiTokenTypeSpecificData;
-pub mod create_tokens_transaction_request_from_address_ri_token_type_specific_data_bitcoin_omni_token;
-pub use self::create_tokens_transaction_request_from_address_ri_token_type_specific_data_bitcoin_omni_token::CreateTokensTransactionRequestFromAddressRiTokenTypeSpecificDataBitcoinOmniToken;
-pub mod create_tokens_transaction_request_from_address_ri_token_type_specific_data_ethereum_erc20_token;
-pub use self::create_tokens_transaction_request_from_address_ri_token_type_specific_data_ethereum_erc20_token::CreateTokensTransactionRequestFromAddressRiTokenTypeSpecificDataEthereumErc20Token;
+pub mod create_tokens_transaction_request_from_address_ris;
+pub use self::create_tokens_transaction_request_from_address_ris::CreateTokensTransactionRequestFromAddressRis;
+pub mod create_tokens_transaction_request_from_address_risb;
+pub use self::create_tokens_transaction_request_from_address_risb::CreateTokensTransactionRequestFromAddressRisb;
+pub mod create_tokens_transaction_request_from_address_rise;
+pub use self::create_tokens_transaction_request_from_address_rise::CreateTokensTransactionRequestFromAddressRise;
 pub mod delete_automatic_coins_forwarding_r;
 pub use self::delete_automatic_coins_forwarding_r::DeleteAutomaticCoinsForwardingR;
 pub mod delete_automatic_coins_forwarding_r_data;
@@ -268,18 +292,18 @@ pub mod feature_mainnets_not_allowed_for_plan;
 pub use self::feature_mainnets_not_allowed_for_plan::FeatureMainnetsNotAllowedForPlan;
 pub mod feature_mainnets_not_allowed_for_plan_error;
 pub use self::feature_mainnets_not_allowed_for_plan_error::FeatureMainnetsNotAllowedForPlanError;
-pub mod generate_receiving_address_r;
-pub use self::generate_receiving_address_r::GenerateReceivingAddressR;
-pub mod generate_receiving_address_r_data;
-pub use self::generate_receiving_address_r_data::GenerateReceivingAddressRData;
-pub mod generate_receiving_address_rb;
-pub use self::generate_receiving_address_rb::GenerateReceivingAddressRb;
-pub mod generate_receiving_address_rb_data;
-pub use self::generate_receiving_address_rb_data::GenerateReceivingAddressRbData;
-pub mod generate_receiving_address_rb_data_item;
-pub use self::generate_receiving_address_rb_data_item::GenerateReceivingAddressRbDataItem;
-pub mod generate_receiving_address_ri;
-pub use self::generate_receiving_address_ri::GenerateReceivingAddressRi;
+pub mod generate_deposit_address_r;
+pub use self::generate_deposit_address_r::GenerateDepositAddressR;
+pub mod generate_deposit_address_r_data;
+pub use self::generate_deposit_address_r_data::GenerateDepositAddressRData;
+pub mod generate_deposit_address_rb;
+pub use self::generate_deposit_address_rb::GenerateDepositAddressRb;
+pub mod generate_deposit_address_rb_data;
+pub use self::generate_deposit_address_rb_data::GenerateDepositAddressRbData;
+pub mod generate_deposit_address_rb_data_item;
+pub use self::generate_deposit_address_rb_data_item::GenerateDepositAddressRbDataItem;
+pub mod generate_deposit_address_ri;
+pub use self::generate_deposit_address_ri::GenerateDepositAddressRi;
 pub mod get_address_details_r;
 pub use self::get_address_details_r::GetAddressDetailsR;
 pub mod get_address_details_r_data;
@@ -640,10 +664,10 @@ pub mod list_assets_details_ri_asset_logo;
 pub use self::list_assets_details_ri_asset_logo::ListAssetsDetailsRiAssetLogo;
 pub mod list_assets_details_ri_latest_rate;
 pub use self::list_assets_details_ri_latest_rate::ListAssetsDetailsRiLatestRate;
-pub mod list_assets_details_ri_specific_data;
-pub use self::list_assets_details_ri_specific_data::ListAssetsDetailsRiSpecificData;
-pub mod list_assets_details_ri_specific_data_crypto_type_data;
-pub use self::list_assets_details_ri_specific_data_crypto_type_data::ListAssetsDetailsRiSpecificDataCryptoTypeData;
+pub mod list_assets_details_ris;
+pub use self::list_assets_details_ris::ListAssetsDetailsRis;
+pub mod list_assets_details_risc;
+pub use self::list_assets_details_risc::ListAssetsDetailsRisc;
 pub mod list_blockchain_events_subscriptions_r;
 pub use self::list_blockchain_events_subscriptions_r::ListBlockchainEventsSubscriptionsR;
 pub mod list_blockchain_events_subscriptions_r_data;
@@ -656,6 +680,12 @@ pub mod list_coins_forwarding_automations_r_data;
 pub use self::list_coins_forwarding_automations_r_data::ListCoinsForwardingAutomationsRData;
 pub mod list_coins_forwarding_automations_ri;
 pub use self::list_coins_forwarding_automations_ri::ListCoinsForwardingAutomationsRi;
+pub mod list_deposit_addresses_r;
+pub use self::list_deposit_addresses_r::ListDepositAddressesR;
+pub mod list_deposit_addresses_r_data;
+pub use self::list_deposit_addresses_r_data::ListDepositAddressesRData;
+pub mod list_deposit_addresses_ri;
+pub use self::list_deposit_addresses_ri::ListDepositAddressesRi;
 pub mod list_hd_wallet_x_pub_y_pub_z_pub_transactions_r;
 pub use self::list_hd_wallet_x_pub_y_pub_z_pub_transactions_r::ListHdWalletXPubYPubZPubTransactionsR;
 pub mod list_hd_wallet_x_pub_y_pub_z_pub_transactions_r_data;
@@ -712,12 +742,6 @@ pub mod list_omni_transactions_by_block_height_ri_recipients;
 pub use self::list_omni_transactions_by_block_height_ri_recipients::ListOmniTransactionsByBlockHeightRiRecipients;
 pub mod list_omni_transactions_by_block_height_ri_senders;
 pub use self::list_omni_transactions_by_block_height_ri_senders::ListOmniTransactionsByBlockHeightRiSenders;
-pub mod list_receiving_addresses_r;
-pub use self::list_receiving_addresses_r::ListReceivingAddressesR;
-pub mod list_receiving_addresses_r_data;
-pub use self::list_receiving_addresses_r_data::ListReceivingAddressesRData;
-pub mod list_receiving_addresses_ri;
-pub use self::list_receiving_addresses_ri::ListReceivingAddressesRi;
 pub mod list_supported_assets_r;
 pub use self::list_supported_assets_r::ListSupportedAssetsR;
 pub mod list_supported_assets_r_data;
@@ -1176,28 +1200,34 @@ pub mod transaction_mined_data_item;
 pub use self::transaction_mined_data_item::TransactionMinedDataItem;
 pub mod transaction_mined_data_item_mined_in_block;
 pub use self::transaction_mined_data_item_mined_in_block::TransactionMinedDataItemMinedInBlock;
-pub mod transaction_request_approve;
-pub use self::transaction_request_approve::TransactionRequestApprove;
-pub mod transaction_request_approve_data;
-pub use self::transaction_request_approve_data::TransactionRequestApproveData;
-pub mod transaction_request_approve_data_item;
-pub use self::transaction_request_approve_data_item::TransactionRequestApproveDataItem;
+pub mod transaction_request_approval;
+pub use self::transaction_request_approval::TransactionRequestApproval;
+pub mod transaction_request_approval_data;
+pub use self::transaction_request_approval_data::TransactionRequestApprovalData;
+pub mod transaction_request_approval_data_item;
+pub use self::transaction_request_approval_data_item::TransactionRequestApprovalDataItem;
 pub mod transaction_request_broadcasted;
 pub use self::transaction_request_broadcasted::TransactionRequestBroadcasted;
 pub mod transaction_request_broadcasted_data;
 pub use self::transaction_request_broadcasted_data::TransactionRequestBroadcastedData;
 pub mod transaction_request_broadcasted_data_item;
 pub use self::transaction_request_broadcasted_data_item::TransactionRequestBroadcastedDataItem;
+pub mod transaction_request_fail;
+pub use self::transaction_request_fail::TransactionRequestFail;
+pub mod transaction_request_fail_data;
+pub use self::transaction_request_fail_data::TransactionRequestFailData;
+pub mod transaction_request_fail_data_item;
+pub use self::transaction_request_fail_data_item::TransactionRequestFailDataItem;
 pub mod transaction_request_mined;
 pub use self::transaction_request_mined::TransactionRequestMined;
 pub mod transaction_request_mined_data;
 pub use self::transaction_request_mined_data::TransactionRequestMinedData;
-pub mod transaction_request_reject;
-pub use self::transaction_request_reject::TransactionRequestReject;
-pub mod transaction_request_reject_data;
-pub use self::transaction_request_reject_data::TransactionRequestRejectData;
-pub mod transaction_request_reject_data_item;
-pub use self::transaction_request_reject_data_item::TransactionRequestRejectDataItem;
+pub mod transaction_request_rejection;
+pub use self::transaction_request_rejection::TransactionRequestRejection;
+pub mod transaction_request_rejection_data;
+pub use self::transaction_request_rejection_data::TransactionRequestRejectionData;
+pub mod transaction_request_rejection_data_item;
+pub use self::transaction_request_rejection_data_item::TransactionRequestRejectionDataItem;
 pub mod unexpected_server_error;
 pub use self::unexpected_server_error::UnexpectedServerError;
 pub mod unexpected_server_error_error;
